@@ -13,7 +13,7 @@ use Wikibase::Datatype::Print::Value::Monolingual;
 
 Readonly::Array our @EXPORT_OK => qw(print);
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub print {
 	my ($obj, $opts_hr) = @_;
@@ -76,17 +76,20 @@ Wikibase::Datatype::Print::Form - Wikibase form pretty print helpers.
  use Wikibase::Datatype::Print::Form qw(print);
 
  my $pretty_print_string = print($obj, $opts_hr);
+ my @pretty_print_lines = print($obj, $opts_hr);
 
 =head1 SUBROUTINES
 
 =head2 C<print>
 
  my $pretty_print_string = print($obj, $opts_hr);
+ my @pretty_print_lines = print($obj, $opts_hr);
 
 Construct pretty print output for L<Wikibase::Datatype::Form>
 object.
 
-Returns string.
+Returns string in scalar context.
+Returns list of lines in array context.
 
 =head1 ERRORS
 
@@ -189,7 +192,7 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.12
+0.13
 
 =cut
 
