@@ -14,7 +14,7 @@ use Wikibase::Datatype::Print::Value::Monolingual;
 
 Readonly::Array our @EXPORT_OK => qw(print);
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub print {
 	my ($obj, $opts_hr) = @_;
@@ -73,17 +73,20 @@ Wikibase::Datatype::Print::Item - Wikibase item pretty print helpers.
  use Wikibase::Datatype::Print::Item qw(print);
 
  my $pretty_print_string = print($obj, $opts_hr);
+ my @pretty_print_lines = print($obj, $opts_hr);
 
 =head1 SUBROUTINES
 
 =head2 C<print>
 
  my $pretty_print_string = print($obj, $opts_hr);
+ my @pretty_print_lines = print($obj, $opts_hr);
 
 Construct pretty print output for L<Wikibase::Datatype::Item>
 object.
 
-Returns string.
+Returns string in scalar context.
+Returns list of lines in array context.
 
 =head1 ERRORS
 
@@ -340,7 +343,7 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.12
+0.13
 
 =cut
 
