@@ -10,7 +10,7 @@ use Wikibase::Datatype::Print::Value;
 
 Readonly::Array our @EXPORT_OK => qw(print);
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub print {
 	my ($obj, $opts_hr) = @_;
@@ -62,17 +62,20 @@ Wikibase::Datatype::Print::MediainfoSnak - Wikibase mediainfo snak pretty print
  use Wikibase::Datatype::Print::MediainfoSnak qw(print);
 
  my $pretty_print_string = print($obj, $opts_hr);
+ my @pretty_print_lines = print($obj, $opts_hr);
 
 =head1 SUBROUTINES
 
 =head2 C<print>
 
  my $pretty_print_string = print($obj, $opts_hr);
+ my @pretty_print_lines = print($obj, $opts_hr);
 
 Construct pretty print output for L<Wikibase::Datatype::MediainfoSnak>
 object.
 
-Returns string.
+Returns string in scalar context.
+Returns list of lines in array context.
 
 =head1 ERRORS
 
@@ -175,7 +178,7 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.12
+0.13
 
 =cut
 
